@@ -1,5 +1,5 @@
 /*
- * Copyright 2000-2002 by Hans Reiser, licensing governed by reiserfs/README
+ * Copyright 2000-2003 by Hans Reiser, licensing governed by reiserfs/README
  */
 
 #include "debugreiserfs.h"
@@ -536,7 +536,11 @@ int main (int argc, char * argv[])
 		 file_name, error ? strerror (error) : "no filesystem found");
 	exit(1) ;
     }
-    reiserfs_open_journal (fs, data (fs)->journal_device_name, O_RDONLY);
+    
+    if (!reiserfs_open_journal (fs, data (fs)->journal_device_name, O_RDONLY)) {
+	fprintf(stderr, "\ndebugreiserfs: Failed to open the fs journal.\n");
+	exit(1);
+    }
 
     switch (debug_mode (fs)) {
     case DO_STAT:
