@@ -1,5 +1,5 @@
 /*
- * Copyright 1996-2002  Hans Reiser
+ * Copyright 1996-2003  Hans Reiser
  */
 #include "fsck.h"
 #include <getopt.h>
@@ -21,7 +21,7 @@ fsck_progress ("Usage: %s [mode] [options] "\
 "\n"\
 "Modes:\n"\
 "  --check\t\tconsistency checking (default)\n"\
-"  --fix-fixable\t\tfix corruptions which can be fixed w/o --rebuild-tree\n"\
+"  --fix-fixable\t\tfix corruptions which can be fixed without --rebuild-tree\n"\
 "  --rebuild-sb\t\tsuper block checking and rebuilding if needed\n"\
 "  \t\t\t(require rebuild-tree afterwards)\n"\
 "  --rebuild-tree\tforce fsck to rebuild filesystem from scratch\n"\
@@ -55,7 +55,7 @@ fsck_progress ("Usage: %s [mode] [options] "\
         fixes indirect pointers pointed to
 	badblocks, adds badblocks to badblock list in fs.
     and with --rebuild
-        builds the tree w/out pointers to badblocks (internal,
+        builds the tree without pointers to badblocks (internal,
 	indirect), adds badblocks to badblock list in fs.  
 */
 
@@ -312,7 +312,7 @@ static char * parse_options (struct fsck_data * data, int argc, char * argv [])
   ** If you are using the latest reiserfsprogs and  it fails **\n\
   ** please  email bug reports to reiserfs-list@namesys.com, **\n\
   ** providing  as  much  information  as  possible --  your **\n\
-  ** hardware,  kernel,  patches,  settings,  all  reiserfsk **\n\
+  ** hardware,  kernel,  patches,  settings,  all reiserfsck **\n\
   ** messages  (including version),  the reiserfsck logfile, **\n\
   ** check  the  syslog file  for  any  related information. **\n\
   ** If you would like advice on using this program, support **\n\
@@ -344,7 +344,7 @@ void warn_what_will_be_done (char * file_name, struct fsck_data * data)
 	reiserfs_warning (warn_to, 
 	    "Will check consistency of the filesystem on %s\n", file_name);
         reiserfs_warning (warn_to, 
-	    "and will fix what can be fixed w/o --rebuild-tree\n");
+	    "and will fix what can be fixed without --rebuild-tree\n");
 	break;
 
     case FSCK_SB:
@@ -806,7 +806,7 @@ static void prepare_fs_for_check(reiserfs_filsys_t * fs)
         }
 
 	if (!is_mounted_read_only (fs->fs_file_name)) {
-	    fsck_progress ("Partition %s is mounted w/ write permissions, cannot check it\n",
+	    fsck_progress ("Partition %s is mounted with write permissions, cannot check it\n",
 			   fs->fs_file_name);
 	    reiserfs_close (fs);
 	    exit(16);
