@@ -1,5 +1,5 @@
 /*
- * Copyright 1996-2002 Hans Reiser
+ * Copyright 1996-2003 Hans Reiser
  */
 
 #include "fsck.h"
@@ -691,7 +691,7 @@ static void pass0_correct_leaf (reiserfs_filsys_t * fs,
 			"change the type of the key %k to StatData\n", bh->b_blocknr, i + 1, &(ih + 1)->ih_key);
                     set_type_and_offset (KEY_FORMAT_1, &(ih + 1)->ih_key, SD_OFFSET, TYPE_STAT_DATA);
 		    dirty = 1;
-                } else {
+                } else if (is_indirect_ih(ih)) {
                     fsck_log("pass0: vpf-10420: block %lu, item %d: Wrong order of items - "
 			"change the type of the key %k to Direct\n", bh->b_blocknr, i+1, &(ih + 1)->ih_key);
                     set_type (get_ih_key_format(ih+1), &(ih + 1)->ih_key, TYPE_DIRECT);
@@ -968,6 +968,7 @@ static void pass0_correct_leaf (reiserfs_filsys_t * fs,
                     goto start_again;
                 }
 		
+		/* Check the lenght of the direct item; offset should be ok already. */
 		if (is_direct_ih (ih)) {
 		    if (STORE_TAIL_IN_UNFM (get_offset (&ih->ih_key) + get_ih_item_len (ih) - 1, 
 			    get_ih_item_len (ih), bh->b_size)) 
@@ -1001,7 +1002,9 @@ static void pass0_correct_leaf (reiserfs_filsys_t * fs,
 		    }
 		} else if (is_direct_ih (ih)) {
 		    if (!correct_direct_item_offset (get_offset (&ih->ih_key), key_format (&ih->ih_key)) ||
-          		STORE_TAIL_IN_UNFM (offset + get_ih_item_len (ih) - 1, get_ih_item_len (ih), bh->b_size)) {
+			((get_offset (&ih->ih_key) % bh->b_size - 1) + get_ih_item_len (ih) > bh->b_size) || 
+          		STORE_TAIL_IN_UNFM (offset + get_ih_item_len (ih) - 1, get_ih_item_len (ih), bh->b_size)) 
+		    {
                             fsck_log("pass0: vpf-10210: block %lu, item %d: The item with wrong offset ", 
                                 bh->b_blocknr, i);
                             fsck_log("or length found %k, len % lu - deleted\n", &ih->ih_key, get_ih_item_len (ih));
@@ -1266,11 +1269,14 @@ static void pass0_correct_leaf (reiserfs_filsys_t * fs,
 	/* pass 1 will skip this */
 	pass_0_stat (fs)->all_contents_removed ++;
 //	fsck_log ("pass0: block %lu: All items were deleted.\n", bh->b_blocknr);
+	dirty = 0;
+	mark_buffer_clean (bh);
     } else {
 	/* pass1 will use this bitmap */
 	pass0_mark_leaf (bh->b_blocknr);
 	/*fsck_data (fs)->rebuild.leaves ++;*/
     }
+    
     if (dirty) {
 	pass_0_stat (fs)->leaves_corrected ++;
 	mark_buffer_dirty (bh);
