@@ -1,5 +1,5 @@
 /*
- * Copyright 1996-2002 Hans Reiser
+ * Copyright 1996-2003 Hans Reiser
  */
 
 #include "fsck.h"
@@ -494,21 +494,21 @@ static void do_pass_2 (reiserfs_filsys_t * fs) {
 	    if (bh == 0) {
 	        fsck_log ("pass_2: Reading of the block (%lu) failed on the device 0x%x\n",
 		      j, fs->fs_dev);
-                goto next;
+                goto cont;
             }
 	
             if (is_block_used (bh->b_blocknr) && !(block_of_journal (fs, bh->b_blocknr) &&
 					       fsck_data(fs)->rebuild.use_journal_area)) {
-	        fsck_log ("%s: The block (%lu) is in the tree already. Should not happen.\n", 
+		fsck_log("%s: The block (%lu) is in the tree already. Should not happen.\n", 
 		    __FUNCTION__, bh->b_blocknr);
-	        goto next;
+		goto cont;
             }
             /* this must be leaf */
             what_node = who_is_this (bh->b_data, bh->b_size);
 	    if (what_node != THE_LEAF) { // || B_IS_KEYS_LEVEL(bh)) {
 	        fsck_log ("%s: The block (%b), marked as a leaf on the first two passes, is not a leaf! Will be skipped.\n", 
 		    __FUNCTION__, bh);
-	        goto next;
+	        goto cont;
 	    }
 /*	
 	    fsck_log ("block %lu is being inserted\n", bh->b_blocknr);
@@ -525,7 +525,7 @@ static void do_pass_2 (reiserfs_filsys_t * fs) {
                 put_stat_data_items (bh);
 
             print_how_far (fsck_progress_file (fs), &done, total, 1, fsck_quiet (fs));
-        next:
+        cont:
 	    brelse (bh);
 	    j ++;
         }
