@@ -1,5 +1,5 @@
 /*
- * Copyright 1996-2002 Hans Reiser
+ * Copyright 1996-2003 Hans Reiser
  */
 #include "fsck.h"
 
@@ -719,11 +719,11 @@ static int append_to_unformatted_node (struct item_head * comingih, struct item_
     free_space = get_offset (&ih->ih_key) + fs->fs_blocksize * I_UNFM_NUM (ih) - get_offset (&comingih->ih_key);
 	
     if (free_space < coming_len)
-	reiserfs_panic ("%s: block %lu: The unformatted node %u, pointed by the file %k, has not enough free space"
+	reiserfs_panic ("%s: block %lu: The unformatted node %u, pointed by the file %k, does not have enough free space"
 	    "for appending %llu bytes", __FUNCTION__, bh->b_blocknr, unfm_ptr, &ih->ih_key, coming_len);
 	
     if (fs->fs_blocksize < free_space)
-	reiserfs_panic ("%s: block %lu: The unformatted node %u, pointed by the file %k, has not enough free space"
+	reiserfs_panic ("%s: block %lu: The unformatted node %u, pointed by the file %k, does not have enough free space"
 	    "for appending %llu bytes", __FUNCTION__, bh->b_blocknr, &ih->ih_key, unfm_ptr, &ih->ih_key, coming_len);	
     
     end_of_data = fs->fs_blocksize - free_space;
@@ -1093,7 +1093,7 @@ check_again:
         copy_short_key (&key, &(ih->ih_key));
 	
         if (reiserfs_search_by_key_4 (fs, &key, &path) != ITEM_FOUND) {
-            fsck_log ("vpf-10260: The file we are inserting the new item (%H) into has not"
+            fsck_log ("vpf-10260: The file we are inserting the new item (%H) into has no"
 		" StatData, insertion was skipped\n", ih);
             pathrelse (&path);
             return 0;
