@@ -1,5 +1,5 @@
 /*
- * Copyright 1996-2002 by Hans Reiser, licensing governed by reiserfs/README
+ * Copyright 1996-2003 by Hans Reiser, licensing governed by reiserfs/README
  */
   
 /*
@@ -1168,17 +1168,19 @@ struct unfm_nodeinfo {
 #define MAX_KEY2_OFFSET  0xfffffffffffffffLL
 
 /* this is aggressive tail suppression policy taken from the kernel */
+/* It should be MAX_DIRECT_ITEM_LEN used here, but sometimes it is not enough,
+ * and items got deleted. */
 #define STORE_TAIL_IN_UNFM(n_file_size,n_tail_size,n_block_size) \
 (\
   (!(n_tail_size)) || \
-  (((n_tail_size) > MAX_DIRECT_ITEM_LEN(n_block_size)) || \
+  (((n_tail_size) > MAX_ITEM_LEN(n_block_size)) || \
    ( (n_file_size) >= (n_block_size) * 4 ) || \
    ( ( (n_file_size) >= (n_block_size) * 3 ) && \
-     ( (n_tail_size) >=   (MAX_DIRECT_ITEM_LEN(n_block_size))/4) ) || \
+     ( (n_tail_size) >=   (MAX_ITEM_LEN(n_block_size))/4) ) || \
    ( ( (n_file_size) >= (n_block_size) * 2 ) && \
-     ( (n_tail_size) >=   (MAX_DIRECT_ITEM_LEN(n_block_size))/2) ) || \
+     ( (n_tail_size) >=   (MAX_ITEM_LEN(n_block_size))/2) ) || \
    ( ( (n_file_size) >= (n_block_size) ) && \
-     ( (n_tail_size) >=   (MAX_DIRECT_ITEM_LEN(n_block_size) * 3)/4) ) ) \
+     ( (n_tail_size) >=   (MAX_ITEM_LEN(n_block_size) * 3)/4) ) ) \
 )
 
 
@@ -1435,7 +1437,7 @@ struct buffer_info {
 #define B_I_STAT_DATA(bh, ih) ( (struct stat_data * )B_I_PITEM(bh,ih) )
 
 #define MAX_DIRECT_ITEM_LEN(size) ((size) - BLKH_SIZE - 2*IH_SIZE - SD_SIZE - UNFM_P_SIZE)
-#define MAX_INDIRECT_ITEM_LEN(size) ((size) - BLKH_SIZE - IH_SIZE)
+#define MAX_INDIRECT_ITEM_LEN(size) MAX_ITEM_LEN(size)
 
 /* indirect items consist of entries which contain blocknrs, pos
    indicates which entry, and B_I_POS_UNFM_POINTER resolves to the
