@@ -480,21 +480,6 @@ int reiserfs_open_journal (reiserfs_filsys_t * fs, char * j_filename, int flags)
 	return 0;
     }
 	
-    j_head = (struct reiserfs_journal_header *)(bh->b_data);
-
-    if (get_jp_journal_1st_block (&j_head->jh_journal) != get_jp_journal_1st_block (sb_jp (sb)) || 
-        get_jp_journal_dev (&j_head->jh_journal) != get_jp_journal_dev (sb_jp (sb)) || 
-        get_jp_journal_size (&j_head->jh_journal) != get_jp_journal_size (sb_jp (sb))) 
-    {
-	reiserfs_warning (stderr, 
-	    "\nreiserfs_open_journal: journal parameters from the super block does not match \n"
-	    "to journal parameters from the journal. It is expected if you created your fs \n"
-	    "with old reiserfsprogs. In this case rebuild-sb will fix it all for you.\n", j_filename);
-        brelse (bh);
-        return 0;
-        
-    }
-
     if (!is_reiserfs_jr_magic_string (sb)) {    
 	if (get_jp_journal_dev (sb_jp(sb)) != 0 || 
 	    get_jp_journal_1st_block (sb_jp(sb)) != get_journal_start_must (fs) || 
@@ -504,7 +489,20 @@ int reiserfs_open_journal (reiserfs_filsys_t * fs, char * j_filename, int flags)
             brelse (bh);
             return 0;
 	}
-	    
+    } else {
+	j_head = (struct reiserfs_journal_header *)(bh->b_data);
+
+	if (get_jp_journal_1st_block (&j_head->jh_journal) != get_jp_journal_1st_block (sb_jp (sb)) || 
+	    get_jp_journal_dev (&j_head->jh_journal) != get_jp_journal_dev (sb_jp (sb)) || 
+	    get_jp_journal_size (&j_head->jh_journal) != get_jp_journal_size (sb_jp (sb))) 
+	{
+	    reiserfs_warning (stderr, 
+		"\nreiserfs_open_journal: journal parameters from the super block does not match \n"
+		"to journal parameters from the journal. It is expected if you created your fs \n"
+		"with old reiserfsprogs. In this case rebuild-sb will fix it all for you.\n", j_filename);
+	    brelse (bh);
+	    return 0;
+	}
     }
 
     fs->fs_jh_bh = bh;
